from setuptools import setup

setup(
    name="atk-satish-helloworld",
    version="0.1",
    packages=["atk-satish-helloworld"],
    author="Satish Kumar",
    author_email="satish@aganitha.com",
    description="A 'Hello, World!' package",
)

